intelmq.bots.parsers.n6 package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.parsers.n6 package

## Submodules

## intelmq.bots.parsers.n6.parser_n6stomp module

The source provides a JSON file with a dictionary. The keys of this dict are identifiers and the values are lists of domains.

class intelmq.bots.parsers.n6.parser_n6stomp.N6StompParserBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ParserBot`

  Parse CERT.pl’s n6 feed

  process()

## Module contents